--------------------------------------------------------------------------------------
-- Requirements, Data Requirements, and Data Requirement to Column Mappings Load Script
--
-- SQL Saturday, 1/30/2010, Richmond Va Presentation
-- NORMALIZE METADATA FOR DATA INTEGRATION ANALYSIS
-- Bob Lambert, mailto:Bob@RobertLambert.net, http://robertlambert.net
--
--------------------------------------------------------------------------------------
	
-- Load Requirements
use SQLSatMetadataDemo
go 

delete from ReqmtMapping
delete from DataReqmt
delete from Requirement

declare @LoadDate datetime = Getdate()
declare @LoadUser nvarchar(255) = User

INSERT INTO Requirement
           (RequirementLabel
           ,RequirementText
           ,RequirementNotesText
           ,VersionNumber
           ,ReleaseNumber
           ,PriorityNumber
           ,LoadDateTime
           ,CreatedByUserName
           )
Select Distinct RequirementLabel
		, RequirementText
		, RequirementNotesText
		, VersionNumber
		, ReleaseNumber
		, PriorityNumber
		, @LoadDate
		, @LoadUser
from stg.StageDataRequirements

-- Load Data Requirements

INSERT INTO DataReqmt
           (RequirementId
           ,DataReqmtName
           ,DataReqmtCategoryText
           ,DataReqmtDefinitionText
           ,EffectiveDate
           ,EndDate
           ,LoadDateTime
           ,CreatedByUserName
           )
SELECT Requirement.RequirementId
		, StageDataRequirements.DataReqmtName
		, StageDataRequirements.DataReqmtCategoryText
		, StageDataRequirements.DataReqmtDefinitionText
		, EffectiveDate
		, EndDate
		, @LoadDate
		, @LoadUser
  FROM stg.StageDataRequirements
  Join Requirement on Requirement.RequirementText 
		= StageDataRequirements.RequirementText

-- Load Column to Data Requirement Mappings

INSERT INTO ReqmtMapping
           (DataReqmtId
           ,SubjectAreaId
           ,TableId
           ,ColumnId
           ,Condition
           ,LoadDateTime
           ,CreatedByUserName
           )
Select DataReqmt.DataReqmtId
	, DBTable.SubjectAreaId
	, DBTable.TableId
	, DBColumn.ColumnId
	, null
	, @LoadDate
	, @LoadUser
From stg.StageDataRequirements
Join DBTable on StageDataRequirements.TableName = DBTable.TableName
Join DBColumn on StageDataRequirements.ColumnName = DBColumn.ColumnName
	and DBColumn.TableId = DBTable.TableId
join DataReqmt on DataReqmt.DataReqmtName = StageDataRequirements.DataReqmtName
GO



