--------------------------------------------------------------------------------------
-- Interface Mapping Load Script
--
-- SQL Saturday, 1/30/2010, Richmond Va Presentation
-- NORMALIZE METADATA FOR DATA INTEGRATION ANALYSIS
-- Bob Lambert, mailto:Bob@RobertLambert.net, http://robertlambert.net
--
--------------------------------------------------------------------------------------
	
-- This script loads the Interface, Field, and Interface Mapping tables from the Interface Staging table

use SQLSatMetadataDemo

begin transaction
delete from InterfaceMapping
delete from Field
delete from Interface
commit

begin transaction
declare @LoadDate datetime = Getdate()
declare @LoadUser nvarchar(255) = User
declare @InterfaceName nvarchar(255) 
declare @Direction nvarchar(255)
declare @InterfaceId int

--select --top 1 
--	 @InterfaceName = InterfaceName
--	,@Direction = Direction  
--from stg.StageInternetSales 
--where InterfaceName is not null

INSERT INTO Interface
           (InterfaceNameText
           ,DirectionNameText
           ,LoadDateTime
           ,CreatedByUserName)
    Select distinct
		 InterfaceName
		,Direction
		,@LoadDate
		,@LoadUser
	from stg.StageInternetSales Stage
	where Stage.InterfaceName is not null

select top 1 @InterfaceId = InterfaceId from Interface
inner Join stg.StageInternetSales
	on Interface.InterfaceNameText = stg.StageInternetSales.InterfaceName

INSERT INTO Field
           (InterfaceId
           ,FieldGroupNameText
           ,FieldNameText
           ,DatatypeText
           ,FieldLengthNum
           ,FieldRequiredFlag
           ,ValidValuesText
           ,LoadDateTime
           ,CreatedByUserName)
     Select distinct
		 InterfaceId
		,Stage.SourceTableName 
		,Stage.SourceColumnName
		,Stage.SourceDataType
		,Stage.SourceDataLength
		,Null
		,Null
		,@LoadDate
		,@LoadUser
	from stg.StageInternetSales Stage
	inner join Interface on Stage.InterfaceName = Interface.InterfaceNameText
	where Stage.InterfaceName is not null

INSERT INTO dbo.InterfaceMapping
           (InterfaceId
           ,FieldId
           ,SubjectAreaId
           ,TableId
           ,ColumnId
           ,Transformations
           ,Comments
           ,LoadDateTime
           ,CreatedByUserName)
 Select Field.InterfaceId
		,Field.FieldId
		,DBColumn.SubjectAreaId
		,DBColumn.TableId
		,DBColumn.ColumnId
		,Stage.Transformations
		,Stage.Comments
		,@LoadDate
		,@LoadUser
	from stg.StageInternetSales Stage
	inner join Field on 
		Stage.SourceTableName = Field.FieldGroupNameText 
	and upper(Stage.SourceColumnName) = upper(Field.FieldNameText)	
	inner join DBColumn on upper(Stage.TargetColumnName) = upper(DBColumn.ColumnName)
	inner join DBTable on DBTable.TableId = DBColumn.TableId
			and upper(DBTable.TableName) = upper(Stage.TargetTableName)
	where Stage.InterfaceName is not null

GO

commit
--Select * from Field order by FieldNameText
--select * from InterfaceMapping
